summaryrefslogtreecommitdiff
path: root/src/glade-widget.h
diff options
context:
space:
mode:
authorJoaquin Cuenca Abela <e98cuenc@yahoo.com>2004-01-18 18:37:08 +0000
committerJoaquĆ­n Cuenca Abela <cuenca@src.gnome.org>2004-01-18 18:37:08 +0000
commitaf969838bb529341974651bdffd7a74b1cf0a5ce (patch)
tree191806cc3dd34b1dd5f5a726d392cf9ab5ab047c /src/glade-widget.h
parenta2ac8937bf2808df15d349f369037ad5f2e863d6 (diff)
downloadglade-af969838bb529341974651bdffd7a74b1cf0a5ce.tar.gz
add a glade_signal_copy function. put the signals with a handler on a hash
2004-01-18 Joaquin Cuenca Abela <e98cuenc@yahoo.com> * src/glade-signal.[ch]: add a glade_signal_copy function. * src/glade-widget.[ch]: put the signals with a handler on a hash indexed by the name of the signal. * src/glade-signal-editor.[ch]: rework the UI of the signal editor.
Diffstat (limited to 'src/glade-widget.h')
-rw-r--r--src/glade-widget.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/glade-widget.h b/src/glade-widget.h
index 67642392..51eee0c3 100644
--- a/src/glade-widget.h
+++ b/src/glade-widget.h
@@ -58,7 +58,7 @@ struct _GladeWidget
* GladeWidgetClass.
*/
- GList *signals; /* A list of GladeSignals */
+ GHashTable *signals; /* A table with a list of GladeSignals, indexed by its name */
};
@@ -101,6 +101,7 @@ GladeWidget *glade_widget_get_parent (GladeWidget *widget);
/* Widget signal*/
GList *glade_widget_find_signal (GladeWidget *widget, GladeSignal *signal);
+GList *glade_widget_find_signals_by_name (GladeWidget *widget, const char *name);
void glade_widget_add_signal (GladeWidget *widget, GladeSignal *signal);
void glade_widget_remove_signal (GladeWidget *widget, GladeSignal *signal);